---
title: "Release v0.41.0"
linkTitle: "Release v0.41.0"
date: 2022-12-20
description: >
 Release v0.41.0
---

## Changes since v0.40.1

### Breaking Changes

All __applications configuration__ file should NOT use the `spec.triggerPaths` (marked as deprecated previously), but use `spec.trigger.onCommit.paths` instead. Refer to [application configuration docs](/docs/user-guide/configuration-reference/#deploymenttrigger)

```yaml
apiVersion: pipecd.dev/v1beta1
kind: KubernetesApp
spec:
  name: analysis-by-http
  labels:
    env: example
    team: product
  # Previously, this will NOT be accepted for new version.
  triggerPaths:
    - deployment.yaml
  # Use this pattern instead.
  trigger:
    onCommit:
      paths:
        - deployment.yaml
```

* Remove trigger paths ([#4037](https://github.com/pipe-cd/pipecd/pull/4037))

### New features

From now, you can have a better insight into your application/project's deployment via deployment data visualized by the PipeCD insight feature. Please refer to the [docs](/docs/user-guide/insights/).

![image](/images/insights.png)

* Introduce Insights feature ([#4071](https://github.com/pipe-cd/pipecd/pull/4071))
* Support Cloud Run application for planpreview ([#4079](https://github.com/pipe-cd/pipecd/pull/4079))
* Support setting kubectlVersion via piped config ([#4081](https://github.com/pipe-cd/pipecd/pull/4081))
* Add `spec.trigger.onCommit.ignores` to application config ([#4059](https://github.com/pipe-cd/pipecd/pull/4059))

### Notable Changes

* Improve the health description for Cloud Run live state ([#4085](https://github.com/pipe-cd/pipecd/pull/4085))
* Add `--include-crds` option to include CRDS for Helm ([#4077](https://github.com/pipe-cd/pipecd/pull/4077))
* Ensure newly created revision is ready to receive traffic before going to the next stage ([#4074](https://github.com/pipe-cd/pipecd/pull/4074))
* Update web dependencies ([#4061](https://github.com/pipe-cd/pipecd/pull/4061))
* Use helper "serviceAccountName" on create role binding ([#4054](https://github.com/pipe-cd/pipecd/pull/4054))

### Internal Changes

* Refactor the loadCloudRunManifest function ([#4089](https://github.com/pipe-cd/pipecd/pull/4089))
* Enable to run lint/go on M1 ([#4088](https://github.com/pipe-cd/pipecd/pull/4088))
* Implement lint/go command for local ([#4086](https://github.com/pipe-cd/pipecd/pull/4086))
* Fix the wrong link for tools ([#4083](https://github.com/pipe-cd/pipecd/pull/4083))
* Remove unused docs ([#4082](https://github.com/pipe-cd/pipecd/pull/4082))
* Rename symbol cloudProvider to platformProvider ([#4080](https://github.com/pipe-cd/pipecd/pull/4080))
* Rename Insighs step to resolution ([#4078](https://github.com/pipe-cd/pipecd/pull/4078))
* Fix application store listBy method ([#4075](https://github.com/pipe-cd/pipecd/pull/4075))
* Fix app live resource lister wrong attribute ([#4072](https://github.com/pipe-cd/pipecd/pull/4072))
* Update pull request template ([#4073](https://github.com/pipe-cd/pipecd/pull/4073))
* Update insights doc ([#4070](https://github.com/pipe-cd/pipecd/pull/4070))
* Add the log for detecting pruned manifest ([#4068](https://github.com/pipe-cd/pipecd/pull/4068))
* Better time range based on step to request Insights data ([#4069](https://github.com/pipe-cd/pipecd/pull/4069))
* Update the codeql actoins to v2 ([#4067](https://github.com/pipe-cd/pipecd/pull/4067))
* Make it possible to run the codeql workflow manually ([#4066](https://github.com/pipe-cd/pipecd/pull/4066))
* Update the codeql analysis schedule ([#4065](https://github.com/pipe-cd/pipecd/pull/4065))
* fix description of apiAddress ([#4064](https://github.com/pipe-cd/pipecd/pull/4064))
* Enable deployment frequency and failure rate charts ([#4062](https://github.com/pipe-cd/pipecd/pull/4062))
* Update docs for onCommit.ignores ([#4063](https://github.com/pipe-cd/pipecd/pull/4063))
* Fix bug on parsing empty kubernetes manifest ([#4060](https://github.com/pipe-cd/pipecd/pull/4060))
* Apply cache to store completed Insight chunk ([#4057](https://github.com/pipe-cd/pipecd/pull/4057))
* Update the default resources docs ([#4058](https://github.com/pipe-cd/pipecd/pull/4058))
* Add release command ([#4056](https://github.com/pipe-cd/pipecd/pull/4056))
* Update gen release docs command ([#4055](https://github.com/pipe-cd/pipecd/pull/4055))
* Ensure group version docs ([#4053](https://github.com/pipe-cd/pipecd/pull/4053))
* Update actions-gh-release version to v2.4.0 ([#4052](https://github.com/pipe-cd/pipecd/pull/4052))
* Fix the wrong link for actions-gh-release ([#4051](https://github.com/pipe-cd/pipecd/pull/4051))
* Replace all of pull request numbers with their link because of release note ([#4050](https://github.com/pipe-cd/pipecd/pull/4050))
* Add release commands to make ([#4049](https://github.com/pipe-cd/pipecd/pull/4049))
* Remove unused config ([#4045](https://github.com/pipe-cd/pipecd/pull/4045))
* Use a make command instead of a hack command directly ([#4046](https://github.com/pipe-cd/pipecd/pull/4046))
* Bump decode-uri-component from 0.2.0 to 0.2.2 in /web ([#4048](https://github.com/pipe-cd/pipecd/pull/4048))
* Replace deprecated actions commands with env files ([#4047](https://github.com/pipe-cd/pipecd/pull/4047))
* Remove unused docs ([#4044](https://github.com/pipe-cd/pipecd/pull/4044))
* Add helm 3.8.2 to PipeCD prerequisites ([#4043](https://github.com/pipe-cd/pipecd/pull/4043))
* Fix the release note ([#4042](https://github.com/pipe-cd/pipecd/pull/4042))
